from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.get import ApiForget
from synctera_client.paths.customers_customer_id_watchlists_subscriptions_subscription_id.put import ApiForput


class CustomersCustomerIdWatchlistsSubscriptionsSubscriptionId(
    ApiForget,
    ApiForput,
):
    pass
