from synctera_client.paths.customers_customer_id_disclosures.get import ApiForget
from synctera_client.paths.customers_customer_id_disclosures.post import ApiForpost


class CustomersCustomerIdDisclosures(
    ApiForget,
    ApiForpost,
):
    pass
