from synctera_client.paths.accounts_products.get import ApiForget
from synctera_client.paths.accounts_products.post import ApiForpost


class AccountsProducts(
    ApiForget,
    ApiForpost,
):
    pass
