from synctera_client.paths.spend_controls_spend_control_id.get import ApiForget
from synctera_client.paths.spend_controls_spend_control_id.patch import ApiForpatch


class SpendControlsSpendControlId(
    ApiForget,
    ApiForpatch,
):
    pass
