from synctera_client.paths.ach_transaction_id.get import ApiForget
from synctera_client.paths.ach_transaction_id.patch import ApiForpatch


class AchTransactionId(
    ApiForget,
    ApiForpatch,
):
    pass
