from synctera_client.paths.transactions_internal_transfer_id.get import ApiForget
from synctera_client.paths.transactions_internal_transfer_id.patch import ApiForpatch


class TransactionsInternalTransferId(
    ApiForget,
    ApiForpatch,
):
    pass
