from synctera_client.paths.customers_customer_id_employment_employment_id.get import ApiForget
from synctera_client.paths.customers_customer_id_employment_employment_id.put import ApiForput


class CustomersCustomerIdEmploymentEmploymentId(
    ApiForget,
    ApiForput,
):
    pass
