# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from synctera_client.paths.spend_controls_spend_control_id import Api

from synctera_client.paths import PathValues

path = PathValues.SPEND_CONTROLS_SPEND_CONTROL_ID