from synctera_client.paths.internal_accounts_internal_account_id.get import ApiForget
from synctera_client.paths.internal_accounts_internal_account_id.patch import ApiForpatch


class InternalAccountsInternalAccountId(
    ApiForget,
    ApiForpatch,
):
    pass
