from synctera_client.paths.accounts_account_id_relationships.get import ApiForget
from synctera_client.paths.accounts_account_id_relationships.post import ApiForpost


class AccountsAccountIdRelationships(
    ApiForget,
    ApiForpost,
):
    pass
