from synctera_client.paths.businesses_business_id.get import ApiForget
from synctera_client.paths.businesses_business_id.patch import ApiForpatch


class BusinessesBusinessId(
    ApiForget,
    ApiForpatch,
):
    pass
