# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from synctera_client.paths.webhook_secrets.post import CreateSecret
from synctera_client.paths.webhooks.post import CreateWebhook
from synctera_client.paths.webhooks_webhook_id.delete import DeleteWebhook
from synctera_client.paths.webhooks_webhook_id_events_event_id.get import GetEvent
from synctera_client.paths.webhooks_webhook_id.get import GetWebhook
from synctera_client.paths.webhooks_webhook_id_events.get import ListEvents
from synctera_client.paths.webhooks.get import ListWebhooks
from synctera_client.paths.webhook_secrets.put import ReplaceSecret
from synctera_client.paths.webhooks_webhook_id_events_event_id_resend.post import ResendEvent
from synctera_client.paths.webhook_secrets.delete import RevokeSecret
from synctera_client.paths.webhooks_trigger.post import TriggerEvent
from synctera_client.paths.webhooks_webhook_id.put import UpdateWebhook


class WebhooksApi(
    CreateSecret,
    CreateWebhook,
    DeleteWebhook,
    GetEvent,
    GetWebhook,
    ListEvents,
    ListWebhooks,
    ReplaceSecret,
    ResendEvent,
    RevokeSecret,
    TriggerEvent,
    UpdateWebhook,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
