# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from synctera_client import schemas  # noqa: F401


class PersonalIdType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The type of the personal identifier. This cannot be changed once the personal identifier is created.
One of the following:
* `ITIN` - US Individual Tax Identification Number. Format is 987-65-4321. Country code will default to US.
* `PASSPORT_NUMBER` - Passport Number. Format varies by country. Country code is required.
* `SIN` - Canadian Social Insurance Number. Format is 123-456-789. Country code will default to CA.
* `SSN` - US Social Security Number. Format is 123-45-6789. Country code will default to US.

    """
    
    @schemas.classproperty
    def ITIN(cls):
        return cls("ITIN")
    
    @schemas.classproperty
    def PASSPORT_NUMBER(cls):
        return cls("PASSPORT_NUMBER")
    
    @schemas.classproperty
    def SIN(cls):
        return cls("SIN")
    
    @schemas.classproperty
    def SSN(cls):
        return cls("SSN")
