from synctera_client.paths.customers_customer_id_watchlists_alerts_alert_id.get import ApiForget
from synctera_client.paths.customers_customer_id_watchlists_alerts_alert_id.put import ApiForput


class CustomersCustomerIdWatchlistsAlertsAlertId(
    ApiForget,
    ApiForput,
):
    pass
